/*
 *  too_bar.h - user-defined toolbar
 *
 *  Copyright (c) 2007-2008 Tobias Doerffel <tobydox/at/users/dot/sf/dot/net>
 *  
 *  This file is part of iTALC - http://italc.sourceforge.net
 *
 *  This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 *  USA.
 */


#ifndef _TOOL_BAR_H
#define _TOOL_BAR_H


#include <QtGui/QToolBar>


class toolBar : public QToolBar
{
	Q_OBJECT
public:
	toolBar( const QString & _title, QWidget * _parent );
	virtual ~toolBar();


private:
	virtual void contextMenuEvent( QContextMenuEvent * _e );
	virtual void paintEvent( QPaintEvent * _pe );


private slots:
	void toggleButton( QAction * );

} ;






#endif

